@@ -10,12 +10,13 @@ test_that("Widget", {
   # create package and 
   pkg <- create_tmp_package()
   setwd(pkg)
+  on.exit({
+    setwd(wd)
+    delete_tmp_package(pkg)
+  })
 
   expect_error(scaffold_widget())
   expect_output(scaffold_widget("writeH1", edit = FALSE))
   expect_output(scaffold_widget("writeH2", edit = FALSE))
-  expect_message(packer::bundle())
-
-  setwd(wd)
-  delete_tmp_package(pkg)
+  expect_message(bundle())
 })
